@@ -165,7 +165,7 @@ def bsfcmap(df, speed_name, torque_name, bsfc_name, title, level):
 
 
 # dutycycle | 20.dec.10
-def dutycycle(df, speed_name, torque_name, stepx, stepy, bubblesize, title):
+def dutycycle(df, speed_name, torque_name, stepx, stepy, bubblesize, xlimleft,xlimright,ylimleft,ylimright,title):
     from scipy.interpolate import griddata
     import matplotlib.pyplot as plt
     import pandas as pd
@@ -177,9 +177,18 @@ def dutycycle(df, speed_name, torque_name, stepx, stepy, bubblesize, title):
 
     x1 = int((min(x) - 200) / 100) * 100
     x2 = int((max(x) + 200) / 100) * 100
+
     y1 = int((min(y) - 200) / 100) * 100
     y2 = int((max(y) + 200) / 100) * 100
 
+    # if type=='realtorque':
+    #     y1 = int((min(y) - 200) / 100) * 100
+    #     y2 = int((max(y) + 200) / 100) * 100
+    # else: # torque percentage
+    #     y1=min(y)
+    #     y2=max(y)
+
+
     xedges = [*range(x1, x2, stepx)]
     yedges = [*range(y1, y2, stepy)]
 
@@ -197,12 +206,21 @@ def dutycycle(df, speed_name, torque_name, stepx, stepy, bubblesize, title):
     ax.grid(which='both', color='grey', linestyle='--', alpha=0.6)
 
     ax.scatter(xpos, ypos, s=hist * bubblesize, alpha=0.5)
+    ax.set_xlim(xlimleft,xlimright)
+    ax.set_ylim(ylimleft,ylimright)
     ax.set_xlabel(speed_name)
     ax.set_ylabel(torque_name)
     ax.set_title(title)
     plt.show()
 
 
+
+df=pd.read_csv('C:/Users/lx379/Desktop/9_1.csv')
+dutycycle(df,'ESPDAve(rpm)','TorquePercentage_(%)',100,10,20,0,2000,0,100,'15N KnockDerate Vehicle Dutycycle')
+
+
+
+
 # dutycycle3d plot | 20.dec.14
 def dutycycle3d(df,speed_name, torque_name, barnum, title):
     from mpl_toolkits.mplot3d import Axes3D
@@ -1968,7 +1986,7 @@ def polynominalreg(df,x_parameter,y_parameter,M,title):
 
     #     return func
     err = (func(x, M) - y).std()
-    print(err)
+    # print(err)
 
     labelx = 'Fitted curve {p=' + str(M) + ' | error:' + str(round(err, 3)) + '}'
 
@@ -1980,7 +1998,7 @@ def polynominalreg(df,x_parameter,y_parameter,M,title):
             output = output + '+' + str(round(p_lsq[0][temp], 3)) + 'x^[' + str(M - temp) + ']'
         else:
             output += str(round(p_lsq[0][temp], 3)) + 'x^[' + str(M - temp) + ']'
-    print(output)
+    # print(output)
 
     # 可视化
 #     plt.plot(x_points, real_func(x_points), c='green', lw=2, label='Ideal curve{eg:y=sin(2Π*x)}')
@@ -1999,6 +2017,10 @@ def polynominalreg(df,x_parameter,y_parameter,M,title):
 # Test area (update by 2021/4/26):==============================================
 # df=pd.read_csv('C:/Users/lx379/Python_Tony/tony_lab/showcase_data/network.csv')
 # network02(df, 'entity1', 'entity2', 'relation')
+# df=pd.read_csv('C:/Users/lx379/Python_Tony/tony_lab/showcase_data/m01_pol_reg.csv')
+# polynominalreg(df,'para-1','para-2',5,'demo')
+
+
 
 
 this_is_nothing = 'Below modules are not validated.---------------------👇'
